# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({"id_": "id", "hris_org_structure_id": "hrisOrgStructureId"})
class GetRolesItem(BaseModel):
    """GetRolesItem

    :param id_: id_, defaults to None
    :type id_: float, optional
    :param name: name, defaults to None
    :type name: str, optional
    :param scope: scope, defaults to None
    :type scope: str, optional
    :param hris_org_structure_id: hris_org_structure_id, defaults to None
    :type hris_org_structure_id: str, optional
    """

    def __init__(
        self,
        id_: float = None,
        name: str = None,
        scope: str = None,
        hris_org_structure_id: str = None,
    ):
        if id_ is not None:
            self.id_ = id_
        if name is not None:
            self.name = name
        if scope is not None:
            self.scope = scope
        if hris_org_structure_id is not None:
            self.hris_org_structure_id = hris_org_structure_id
