# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class ExerciseEquityToCreateContainer(BaseModel):
    """ExerciseEquityToCreateContainer

    :param fmv: fmv
    :type fmv: str
    :param quantity: quantity
    :type quantity: float
    :param issuer_id: issuer_id
    :type issuer_id: str
    :param worker_id: worker_id
    :type worker_id: str
    :param address_zip: address_zip
    :type address_zip: str
    :param exercise_id: exercise_id
    :type exercise_id: str
    :param address_city: address_city
    :type address_city: str
    :param address_state: address_state
    :type address_state: str
    :param address_street: address_street
    :type address_street: str
    :param stakeholder_id: stakeholder_id
    :type stakeholder_id: str
    :param address_country: address_country
    :type address_country: str
    :param option_grant_id: option_grant_id
    :type option_grant_id: str
    :param fmv_currency_code: fmv_currency_code
    :type fmv_currency_code: str
    :param stakeholder_email: stakeholder_email
    :type stakeholder_email: str
    :param option_grant_issue: option_grant_issue
    :type option_grant_issue: str
    :param option_grant_label: option_grant_label
    :type option_grant_label: str
    :param option_grant_currency: option_grant_currency
    :type option_grant_currency: str
    :param option_grant_issue_date: option_grant_issue_date
    :type option_grant_issue_date: str
    :param option_grant_expiry_date: option_grant_expiry_date
    :type option_grant_expiry_date: str
    :param stakeholder_relationship: stakeholder_relationship
    :type stakeholder_relationship: str
    :param option_grant_strike_price: option_grant_strike_price
    :type option_grant_strike_price: str
    """

    def __init__(
        self,
        fmv: str,
        quantity: float,
        issuer_id: str,
        worker_id: str,
        address_zip: str,
        exercise_id: str,
        address_city: str,
        address_state: str,
        address_street: str,
        stakeholder_id: str,
        address_country: str,
        option_grant_id: str,
        fmv_currency_code: str,
        stakeholder_email: str,
        option_grant_issue: str,
        option_grant_label: str,
        option_grant_currency: str,
        option_grant_issue_date: str,
        option_grant_expiry_date: str,
        stakeholder_relationship: str,
        option_grant_strike_price: str,
    ):
        self.fmv = fmv
        self.quantity = quantity
        self.issuer_id = issuer_id
        self.worker_id = worker_id
        self.address_zip = address_zip
        self.exercise_id = exercise_id
        self.address_city = address_city
        self.address_state = address_state
        self.address_street = address_street
        self.stakeholder_id = stakeholder_id
        self.address_country = address_country
        self.option_grant_id = option_grant_id
        self.fmv_currency_code = fmv_currency_code
        self.stakeholder_email = stakeholder_email
        self.option_grant_issue = option_grant_issue
        self.option_grant_label = option_grant_label
        self.option_grant_currency = option_grant_currency
        self.option_grant_issue_date = option_grant_issue_date
        self.option_grant_expiry_date = option_grant_expiry_date
        self.stakeholder_relationship = stakeholder_relationship
        self.option_grant_strike_price = option_grant_strike_price
