# This file was generated by liblab | https://liblab.com/

from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({"id_": "id", "permission_sets": "permissionSets"})
class UpdatedRoleContainer(BaseModel):
    """UpdatedRoleContainer

    :param id_: id_, defaults to None
    :type id_: float, optional
    :param name: name, defaults to None
    :type name: str, optional
    :param scope: scope, defaults to None
    :type scope: str, optional
    :param description: description, defaults to None
    :type description: str, optional
    :param permission_sets: permission_sets, defaults to None
    :type permission_sets: List[str], optional
    """

    def __init__(
        self,
        id_: float = None,
        name: str = None,
        scope: str = None,
        description: str = None,
        permission_sets: List[str] = None,
    ):
        if id_ is not None:
            self.id_ = id_
        if name is not None:
            self.name = name
        if scope is not None:
            self.scope = scope
        if description is not None:
            self.description = description
        if permission_sets is not None:
            self.permission_sets = permission_sets
