# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .custom_fields_object import CustomFieldsObject


@JsonMap({})
class CustomFieldItemContainer(BaseModel):
    """CustomFieldItemContainer

    :param data: data
    :type data: CustomFieldsObject
    """

    def __init__(self, data: CustomFieldsObject):
        self.data = self._define_object(data, CustomFieldsObject)
