# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .identifier_value import IdentifierValue, IdentifierValueGuard


@JsonMap({})
class UpdateWorkerWorkingLocation(BaseModel):
    """UpdateWorkerWorkingLocation

    :param working_location_id: working_location_id
    :type working_location_id: IdentifierValue
    """

    def __init__(self, working_location_id: IdentifierValue):
        self.working_location_id = IdentifierValueGuard.return_one_of(
            working_location_id
        )
