# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({"id_": "id"})
class CreatedExerciseEquityContainer(BaseModel):
    """CreatedExerciseEquityContainer

    :param id_: id_
    :type id_: str
    :param status: status
    :type status: str
    :param created_at: created_at
    :type created_at: str
    :param updated_at: updated_at
    :type updated_at: str
    :param employer_approval: employer_approval
    :type employer_approval: str
    """

    def __init__(
        self,
        id_: str,
        status: str,
        created_at: str,
        updated_at: str,
        employer_approval: str,
    ):
        self.id_ = id_
        self.status = status
        self.created_at = created_at
        self.updated_at = updated_at
        self.employer_approval = employer_approval
