# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class ExerciseEquityToUpdateContainer(BaseModel):
    """ExerciseEquityToUpdateContainer

    :param employer_approval: employer_approval
    :type employer_approval: str
    """

    def __init__(self, employer_approval: str):
        self.employer_approval = employer_approval
