# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .identifier_value import IdentifierValue, IdentifierValueGuard


@JsonMap({})
class UpdateWorkerDepartment(BaseModel):
    """UpdateWorkerDepartment

    :param department_id: department_id
    :type department_id: IdentifierValue
    """

    def __init__(self, department_id: IdentifierValue):
        self.department_id = IdentifierValueGuard.return_one_of(department_id)
