# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .employee_tax_documents_list import EmployeeTaxDocumentsList


@JsonMap({})
class EmployeeTaxDocumentsListContainer(BaseModel):
    """EmployeeTaxDocumentsListContainer

    :param data: data
    :type data: List[EmployeeTaxDocumentsList]
    """

    def __init__(self, data: List[EmployeeTaxDocumentsList]):
        self.data = self._define_list(data, EmployeeTaxDocumentsList)
