# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .worker_bank_account_to_add import WorkerBankAccountToAdd


@JsonMap({})
class AddWorkerBankAccountContainer(BaseModel):
    """AddWorkerBankAccountContainer

    :param data: data
    :type data: WorkerBankAccountToAdd
    """

    def __init__(self, data: WorkerBankAccountToAdd):
        self.data = self._define_object(data, WorkerBankAccountToAdd)
