# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .timesheet_review_to_create import TimesheetReviewToCreate


@JsonMap({})
class TimesheetReviewToCreateContainer(BaseModel):
    """TimesheetReviewToCreateContainer

    :param data: data
    :type data: TimesheetReviewToCreate
    """

    def __init__(self, data: TimesheetReviewToCreate):
        self.data = self._define_object(data, TimesheetReviewToCreate)
